pub enum FilterError {
InvalidInput,
InvalidParameter(String),
BadInputSurfaceStatus(Error),
CairoError(Error),
Rendering(InternalRenderingError),
LightingInputTooSmall,
}Expand description
An enumeration of errors that can occur during filter primitive rendering.
Variants
InvalidInput
The filter was passed invalid input (the in attribute).
InvalidParameter(String)
The filter was passed an invalid parameter.
BadInputSurfaceStatus(Error)
The filter input surface has an unsuccessful status.
CairoError(Error)
A Cairo error.
This means that either a failed intermediate surface creation or bad intermediate surface status.
Rendering(InternalRenderingError)
Error from the rendering backend.
LightingInputTooSmall
A lighting filter input surface is too small.